@@ -30,17 +30,14 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \date April 2012
-*
 *> \ingroup single_blas_testing
 *
 *  =====================================================================
       PROGRAM SBLAT1
 *
-*  -- Reference BLAS test routine (version 3.7.0) --
+*  -- Reference BLAS test routine --
 *  -- Reference BLAS is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     April 2012
 *
 *  =====================================================================
 *
@@ -91,6 +88,9 @@
 *
 99999 FORMAT (' Real BLAS Test Program Results',/1X)
 99998 FORMAT ('                                    ----- PASS -----')
+*
+*     End of SBLAT1
+*
       END
       SUBROUTINE HEADER
 *     .. Parameters ..
@@ -122,6 +122,9 @@
       RETURN
 *
 99999 FORMAT (/' Test of subprogram number',I3,12X,A6)
+*
+*     End of HEADER
+*
       END
       SUBROUTINE CHECK0(SFAC)
 *     .. Parameters ..
@@ -139,7 +142,7 @@
       REAL              DA1(8), DATRUE(8), DB1(8), DBTRUE(8), DC1(8),
      +                  DS1(8), DAB(4,9), DTEMP(9), DTRUE(9,9)
 *     .. External Subroutines ..
-      EXTERNAL          SROTG, SROTMG, STEST1
+      EXTERNAL          SROTG, SROTMG, STEST, STEST1
 *     .. Common blocks ..
       COMMON            /COMBLA/ICASE, N, INCX, INCY, PASS
 *     .. Data statements ..
@@ -238,6 +241,9 @@
          END IF
    20 CONTINUE
    40 RETURN
+*
+*     End of CHECK0
+*
       END
       SUBROUTINE CHECK1(SFAC)
 *     .. Parameters ..
@@ -249,11 +255,12 @@
       INTEGER           ICASE, INCX, INCY, N
       LOGICAL           PASS
 *     .. Local Scalars ..
-      INTEGER           I, LEN, NP1
+      INTEGER           I, IX, LEN, NP1
 *     .. Local Arrays ..
       REAL              DTRUE1(5), DTRUE3(5), DTRUE5(8,5,2), DV(8,5,2),
-     +                  SA(10), STEMP(1), STRUE(8), SX(8)
-      INTEGER           ITRUE2(5)
+     +                  DVR(8), SA(10), STEMP(1), STRUE(8), SX(8),
+     +                  SXR(15)
+      INTEGER           ITRUE2(5), ITRUEC(5)
 *     .. External Functions ..
       REAL              SASUM, SNRM2
       INTEGER           ISAMAX
@@ -280,6 +287,8 @@
      +                  0.2E0, 3.0E0, -0.6E0, 5.0E0, 0.3E0, 2.0E0,
      +                  2.0E0, 2.0E0, 0.1E0, 4.0E0, -0.3E0, 6.0E0,
      +                  -0.5E0, 7.0E0, -0.1E0, 3.0E0/
+      DATA              DVR/8.0E0, -7.0E0, 9.0E0, 5.0E0, 9.0E0, 8.0E0,
+     +                  7.0E0, 7.0E0/
       DATA              DTRUE1/0.0E0, 0.3E0, 0.5E0, 0.7E0, 0.6E0/
       DATA              DTRUE3/0.0E0, 0.3E0, 0.7E0, 1.1E0, 1.0E0/
       DATA              DTRUE5/0.10E0, 2.0E0, 2.0E0, 2.0E0, 2.0E0,
@@ -297,6 +306,7 @@
      +                  0.03E0, 4.0E0, -0.09E0, 6.0E0, -0.15E0, 7.0E0,
      +                  -0.03E0, 3.0E0/
       DATA              ITRUE2/0, 1, 2, 2, 3/
+      DATA              ITRUEC/0, 1, 1, 1, 1/
 *     .. Executable Statements ..
       DO 80 INCX = 1, 2
          DO 60 NP1 = 1, 5
@@ -325,13 +335,29 @@
             ELSE IF (ICASE.EQ.10) THEN
 *              .. ISAMAX ..
                CALL ITEST1(ISAMAX(N,SX,INCX),ITRUE2(NP1))
+               DO 100 I = 1, LEN
+                  SX(I) = 42.0E0
+  100          CONTINUE
+               CALL ITEST1(ISAMAX(N,SX,INCX),ITRUEC(NP1))
             ELSE
                WRITE (NOUT,*) ' Shouldn''t be here in CHECK1'
                STOP
             END IF
    60    CONTINUE
+         IF (ICASE.EQ.10) THEN
+            N = 8
+            IX = 1
+            DO 120 I = 1, N
+               SXR(IX) = DVR(I)
+               IX = IX + INCX
+  120       CONTINUE
+            CALL ITEST1(ISAMAX(N,SXR,INCX),3)
+         END IF
    80 CONTINUE
       RETURN
+*
+*     End of CHECK1
+*
       END
       SUBROUTINE CHECK2(SFAC)
 *     .. Parameters ..
@@ -345,7 +371,7 @@
 *     .. Local Scalars ..
       REAL              SA
       INTEGER           I, J, KI, KN, KNI, KPAR, KSIZE, LENX, LENY,
-     $                  MX, MY
+     $                  LINCX, LINCY, MX, MY
 *     .. Local Arrays ..
       REAL              DT10X(7,4,4), DT10Y(7,4,4), DT7(4,4),
      $                  DT8(7,4,4), DX1(7),
@@ -355,7 +381,7 @@
      $                  DT19XB(7,4,4), DT19XC(7,4,4),DT19XD(7,4,4),
      $                  DT19Y(7,4,16), DT19YA(7,4,4),DT19YB(7,4,4),
      $                  DT19YC(7,4,4), DT19YD(7,4,4), DTEMP(5),
-     $                  ST7B(4,4)
+     $                  ST7B(4,4), STY0(1), SX0(1), SY0(1)
       INTEGER           INCXS(4), INCYS(4), LENS(4,2), NS(4)
 *     .. External Functions ..
       REAL              SDOT, SDSDOT
@@ -631,6 +657,23 @@
    60          CONTINUE
                CALL SCOPY(N,SX,INCX,SY,INCY)
                CALL STEST(LENY,SY,STY,SSIZE2(1,1),1.0E0)
+               IF (KI.EQ.1) THEN
+                  SX0(1) = 42.0E0
+                  SY0(1) = 43.0E0
+                  IF (N.EQ.0) THEN
+                     STY0(1) = SY0(1)
+                  ELSE
+                     STY0(1) = SX0(1)
+                  END IF
+                  LINCX = INCX
+                  INCX = 0
+                  LINCY = INCY
+                  INCY = 0
+                  CALL SCOPY(N,SX0,INCX,SY0,INCY)
+                  CALL STEST(1,SY0,STY0,SSIZE2(1,1),1.0E0)
+                  INCX = LINCX
+                  INCY = LINCY
+               END IF
             ELSE IF (ICASE.EQ.6) THEN
 *              .. SSWAP ..
                CALL SSWAP(N,SX,INCX,SY,INCY)
@@ -680,6 +723,9 @@
   100    CONTINUE
   120 CONTINUE
       RETURN
+*
+*     End of CHECK2
+*
       END
       SUBROUTINE CHECK3(SFAC)
 *     .. Parameters ..
@@ -886,6 +932,9 @@
          CALL STEST(5,COPYY,MWPSTY,MWPSTY,SFAC)
   200 CONTINUE
       RETURN
+*
+*     End of CHECK3
+*
       END
       SUBROUTINE STEST(LEN,SCOMP,STRUE,SSIZE,SFAC)
 *     ********************************* STEST **************************
@@ -942,11 +991,14 @@
      +       ' COMP(I)                             TRUE(I)  DIFFERENCE',
      +       '     SIZE(I)',/1X)
 99997 FORMAT (1X,I4,I3,2I5,I3,2E36.8,2E12.4)
+*
+*     End of STEST
+*
       END
       SUBROUTINE STEST1(SCOMP1,STRUE1,SSIZE,SFAC)
 *     ************************* STEST1 *****************************
 *
-*     THIS IS AN INTERFACE SUBROUTINE TO ACCOMODATE THE FORTRAN
+*     THIS IS AN INTERFACE SUBROUTINE TO ACCOMMODATE THE FORTRAN
 *     REQUIREMENT THAT WHEN A DUMMY ARGUMENT IS AN ARRAY, THE
 *     ACTUAL ARGUMENT MUST ALSO BE AN ARRAY OR AN ARRAY ELEMENT.
 *
@@ -967,6 +1019,9 @@
       CALL STEST(1,SCOMP,STRUE,SSIZE,SFAC)
 *
       RETURN
+*
+*     End of STEST1
+*
       END
       REAL             FUNCTION SDIFF(SA,SB)
 *     ********************************* SDIFF **************************
@@ -977,6 +1032,9 @@
 *     .. Executable Statements ..
       SDIFF = SA - SB
       RETURN
+*
+*     End of SDIFF
+*
       END
       SUBROUTINE ITEST1(ICOMP,ITRUE)
 *     ********************************* ITEST1 *************************
@@ -1018,4 +1076,7 @@
      +       ' COMP                                TRUE     DIFFERENCE',
      +       /1X)
 99997 FORMAT (1X,I4,I3,2I5,2I36,I12)
+*
+*     End of ITEST1
+*
       END
