@@ -8,8 +8,8 @@
  */
 #include "cblas.h"
 #include "cblas_f77.h"
-void cblas_sswap( const int N, float *X, const int incX, float *Y,
-                       const int incY)
+void cblas_sswap( const CBLAS_INDEX N, float *X, const CBLAS_INDEX incX, float *Y,
+                       const CBLAS_INDEX incY)
 {
 #ifdef F77_INT
    F77_INT F77_N=N, F77_incX=incX, F77_incY=incY;
