@@ -153,8 +153,6 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \date June 2017
-*
 *> \ingroup complexGEauxiliary
 *
 *> \par Further Details:
@@ -190,10 +188,9 @@
       SUBROUTINE CTGEX2( WANTQ, WANTZ, N, A, LDA, B, LDB, Q, LDQ, Z,
      $                   LDZ, J1, INFO )
 *
-*  -- LAPACK auxiliary routine (version 3.7.1) --
+*  -- LAPACK auxiliary routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     June 2017
 *
 *     .. Scalar Arguments ..
       LOGICAL            WANTQ, WANTZ
@@ -220,8 +217,8 @@
 *     .. Local Scalars ..
       LOGICAL            STRONG, WEAK
       INTEGER            I, M
-      REAL               CQ, CZ, EPS, SA, SB, SCALE, SMLNUM, SS, SUM,
-     $                   THRESH, WS
+      REAL               CQ, CZ, EPS, SA, SB, SCALE, SMLNUM, SUM,
+     $                   THRESHA, THRESHB
       COMPLEX            CDUM, F, G, SQ, SZ
 *     ..
 *     .. Local Arrays ..
@@ -263,8 +260,12 @@
       SUM = REAL( CONE )
       CALL CLACPY( 'Full', M, M, S, LDST, WORK, M )
       CALL CLACPY( 'Full', M, M, T, LDST, WORK( M*M+1 ), M )
-      CALL CLASSQ( 2*M*M, WORK, 1, SCALE, SUM )
+      CALL CLASSQ( M*M, WORK, 1, SCALE, SUM )
       SA = SCALE*SQRT( SUM )
+      SCALE = DBLE( CZERO )
+      SUM = DBLE( CONE )
+      CALL CLASSQ( M*M, WORK(M*M+1), 1, SCALE, SUM )
+      SB = SCALE*SQRT( SUM )
 *
 *     THRES has been changed from
 *        THRESH = MAX( TEN*EPS*SA, SMLNUM )
@@ -274,15 +275,16 @@
 *     "Bug" reported by Ondra Kamenik, confirmed by Julie Langou, fixed by
 *     Jim Demmel and Guillaume Revy. See forum post 1783.
 *
-      THRESH = MAX( TWENTY*EPS*SA, SMLNUM )
+      THRESHA = MAX( TWENTY*EPS*SA, SMLNUM )
+      THRESHB = MAX( TWENTY*EPS*SB, SMLNUM )
 *
 *     Compute unitary QL and RQ that swap 1-by-1 and 1-by-1 blocks
 *     using Givens rotations and perform the swap tentatively.
 *
       F = S( 2, 2 )*T( 1, 1 ) - T( 2, 2 )*S( 1, 1 )
       G = S( 2, 2 )*T( 1, 2 ) - T( 2, 2 )*S( 1, 2 )
-      SA = ABS( S( 2, 2 ) )
-      SB = ABS( T( 2, 2 ) )
+      SA = ABS( S( 2, 2 ) ) * ABS( T( 1, 1 ) )
+      SB = ABS( S( 1, 1 ) ) * ABS( T( 2, 2 ) )
       CALL CLARTG( G, F, CZ, SZ, CDUM )
       SZ = -SZ
       CALL CROT( 2, S( 1, 1 ), 1, S( 1, 2 ), 1, CZ, CONJG( SZ ) )
@@ -295,10 +297,11 @@
       CALL CROT( 2, S( 1, 1 ), LDST, S( 2, 1 ), LDST, CQ, SQ )
       CALL CROT( 2, T( 1, 1 ), LDST, T( 2, 1 ), LDST, CQ, SQ )
 *
-*     Weak stability test: |S21| + |T21| <= O(EPS F-norm((S, T)))
+*     Weak stability test: |S21| <= O(EPS F-norm((A)))
+*                          and  |T21| <= O(EPS F-norm((B)))
 *
-      WS = ABS( S( 2, 1 ) ) + ABS( T( 2, 1 ) )
-      WEAK = WS.LE.THRESH
+      WEAK = ABS( S( 2, 1 ) ).LE.THRESHA .AND. 
+     $ ABS( T( 2, 1 ) ).LE.THRESHB
       IF( .NOT.WEAK )
      $   GO TO 20
 *
@@ -319,11 +322,15 @@
             WORK( I+4 ) = WORK( I+4 ) - B( J1+I-1, J1 )
             WORK( I+6 ) = WORK( I+6 ) - B( J1+I-1, J1+1 )
    10    CONTINUE
-         SCALE = REAL( CZERO )
-         SUM = REAL( CONE )
-         CALL CLASSQ( 2*M*M, WORK, 1, SCALE, SUM )
-         SS = SCALE*SQRT( SUM )
-         STRONG = SS.LE.THRESH
+         SCALE = DBLE( CZERO )
+         SUM = DBLE( CONE )
+         CALL CLASSQ( M*M, WORK, 1, SCALE, SUM )
+         SA = SCALE*SQRT( SUM )
+         SCALE = DBLE( CZERO )
+         SUM = DBLE( CONE )
+         CALL CLASSQ( M*M, WORK(M*M+1), 1, SCALE, SUM )
+         SB = SCALE*SQRT( SUM )
+         STRONG = SA.LE.THRESHA .AND. SB.LE.THRESHB
          IF( .NOT.STRONG )
      $      GO TO 20
       END IF
