@@ -1,9 +1,151 @@
+*> \brief \b DLAED4 used by DSTEDC. Finds a single root of the secular equation.
+*
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at
+*            http://www.netlib.org/lapack/explore-html/
+*
+*> \htmlonly
+*> Download DLAED4 + dependencies
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/dlaed4.f">
+*> [TGZ]</a>
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/dlaed4.f">
+*> [ZIP]</a>
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/dlaed4.f">
+*> [TXT]</a>
+*> \endhtmlonly
+*
+*  Definition:
+*  ===========
+*
+*       SUBROUTINE DLAED4( N, I, D, Z, DELTA, RHO, DLAM, INFO )
+*
+*       .. Scalar Arguments ..
+*       INTEGER            I, INFO, N
+*       DOUBLE PRECISION   DLAM, RHO
+*       ..
+*       .. Array Arguments ..
+*       DOUBLE PRECISION   D( * ), DELTA( * ), Z( * )
+*       ..
+*
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*> This subroutine computes the I-th updated eigenvalue of a symmetric
+*> rank-one modification to a diagonal matrix whose elements are
+*> given in the array d, and that
+*>
+*>            D(i) < D(j)  for  i < j
+*>
+*> and that RHO > 0.  This is arranged by the calling routine, and is
+*> no loss in generality.  The rank-one modified system is thus
+*>
+*>            diag( D )  +  RHO * Z * Z_transpose.
+*>
+*> where we assume the Euclidean norm of Z is 1.
+*>
+*> The method consists of approximating the rational functions in the
+*> secular equation by simpler interpolating rational functions.
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[in] N
+*> \verbatim
+*>          N is INTEGER
+*>         The length of all arrays.
+*> \endverbatim
+*>
+*> \param[in] I
+*> \verbatim
+*>          I is INTEGER
+*>         The index of the eigenvalue to be computed.  1 <= I <= N.
+*> \endverbatim
+*>
+*> \param[in] D
+*> \verbatim
+*>          D is DOUBLE PRECISION array, dimension (N)
+*>         The original eigenvalues.  It is assumed that they are in
+*>         order, D(I) < D(J)  for I < J.
+*> \endverbatim
+*>
+*> \param[in] Z
+*> \verbatim
+*>          Z is DOUBLE PRECISION array, dimension (N)
+*>         The components of the updating vector.
+*> \endverbatim
+*>
+*> \param[out] DELTA
+*> \verbatim
+*>          DELTA is DOUBLE PRECISION array, dimension (N)
+*>         If N > 2, DELTA contains (D(j) - lambda_I) in its  j-th
+*>         component.  If N = 1, then DELTA(1) = 1. If N = 2, see DLAED5
+*>         for detail. The vector DELTA contains the information necessary
+*>         to construct the eigenvectors by DLAED3 and DLAED9.
+*> \endverbatim
+*>
+*> \param[in] RHO
+*> \verbatim
+*>          RHO is DOUBLE PRECISION
+*>         The scalar in the symmetric updating formula.
+*> \endverbatim
+*>
+*> \param[out] DLAM
+*> \verbatim
+*>          DLAM is DOUBLE PRECISION
+*>         The computed lambda_I, the I-th updated eigenvalue.
+*> \endverbatim
+*>
+*> \param[out] INFO
+*> \verbatim
+*>          INFO is INTEGER
+*>         = 0:  successful exit
+*>         > 0:  if INFO = 1, the updating process failed.
+*> \endverbatim
+*
+*> \par Internal Parameters:
+*  =========================
+*>
+*> \verbatim
+*>  Logical variable ORGATI (origin-at-i?) is used for distinguishing
+*>  whether D(i) or D(i+1) is treated as the origin.
+*>
+*>            ORGATI = .true.    origin at i
+*>            ORGATI = .false.   origin at i+1
+*>
+*>   Logical variable SWTCH3 (switch-for-3-poles?) is for noting
+*>   if we are working with THREE poles!
+*>
+*>   MAXIT is the maximum number of iterations allowed for each
+*>   eigenvalue.
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee
+*> \author Univ. of California Berkeley
+*> \author Univ. of Colorado Denver
+*> \author NAG Ltd.
+*
+*> \ingroup auxOTHERcomputational
+*
+*> \par Contributors:
+*  ==================
+*>
+*>     Ren-Cang Li, Computer Science Division, University of California
+*>     at Berkeley, USA
+*>
+*  =====================================================================
       SUBROUTINE DLAED4( N, I, D, Z, DELTA, RHO, DLAM, INFO )
 *
-*  -- LAPACK routine (version 2.0) --
-*     Univ. of Tennessee, Oak Ridge National Lab, Argonne National Lab,
-*     Courant Institute, NAG Ltd., and Rice University
-*     September 30, 1994
+*  -- LAPACK computational routine --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
 *
 *     .. Scalar Arguments ..
       INTEGER            I, INFO, N
@@ -13,77 +155,11 @@
       DOUBLE PRECISION   D( * ), DELTA( * ), Z( * )
 *     ..
 *
-*  Purpose
-*  =======
-*
-*  This subroutine computes the I-th updated eigenvalue of a symmetric
-*  rank-one modification to a diagonal matrix whose elements are
-*  given in the array d, and that
-*
-*             D(i) < D(j)  for  i < j
-*
-*  and that RHO > 0.  This is arranged by the calling routine, and is
-*  no loss in generality.  The rank-one modified system is thus
-*
-*             diag( D )  +  RHO *  Z * Z_transpose.
-*
-*  where we assume the Euclidean norm of Z is 1.
-*
-*  The method consists of approximating the rational functions in the
-*  secular equation by simpler interpolating rational functions.
-*
-*  Arguments
-*  =========
-*
-*  N      (input) INTEGER
-*         The length of all arrays.
-*
-*  I      (input) INTEGER
-*         The index of the eigenvalue to be computed.  1 <= I <= N.
-*
-*  D      (input) DOUBLE PRECISION array, dimension (N)
-*         The original eigenvalues.  It is assumed that they are in
-*         order, D(I) < D(J)  for I < J.
-*
-*  Z      (input) DOUBLE PRECISION array, dimension (N)
-*         The components of the updating vector.
-*
-*  DELTA  (output) DOUBLE PRECISION array, dimension (N)
-*         If N .ne. 1, DELTA contains (D(j) - lambda_I) in its  j-th
-*         component.  If N = 1, then DELTA(1) = 1.  The vector DELTA
-*         contains the information necessary to construct the
-*         eigenvectors.
-*
-*  RHO    (input) DOUBLE PRECISION
-*         The scalar in the symmetric updating formula.
-*
-*  DLAM   (output) DOUBLE PRECISION
-*         The computed lambda_I, the I-th updated eigenvalue.
-*
-*  INFO   (output) INTEGER
-*         = 0:  successful exit
-*         > 0:  if INFO = 1, the updating process failed.
-*
-*  Internal Parameters
-*  ===================
-*
-*  Logical variable ORGATI (origin-at-i?) is used for distinguishing
-*  whether D(i) or D(i+1) is treated as the origin.
-*
-*            ORGATI = .true.    origin at i
-*            ORGATI = .false.   origin at i+1
-*
-*   Logical variable SWTCH3 (switch-for-3-poles?) is for noting
-*   if we are working with THREE poles!
-*
-*   MAXIT is the maximum number of iterations allowed for each
-*   eigenvalue.
-*
 *  =====================================================================
 *
 *     .. Parameters ..
       INTEGER            MAXIT
-      PARAMETER          ( MAXIT = 20 )
+      PARAMETER          ( MAXIT = 30 )
       DOUBLE PRECISION   ZERO, ONE, TWO, THREE, FOUR, EIGHT, TEN
       PARAMETER          ( ZERO = 0.0D0, ONE = 1.0D0, TWO = 2.0D0,
      $                   THREE = 3.0D0, FOUR = 4.0D0, EIGHT = 8.0D0,
@@ -92,8 +168,9 @@
 *     .. Local Scalars ..
       LOGICAL            ORGATI, SWTCH, SWTCH3
       INTEGER            II, IIM1, IIP1, IP1, ITER, J, NITER
-      DOUBLE PRECISION   A, B, C, DEL, DPHI, DPSI, DW, EPS, ERRETM, ETA,
-     $                   PHI, PREW, PSI, RHOINV, TAU, TEMP, TEMP1, W
+      DOUBLE PRECISION   A, B, C, DEL, DLTLB, DLTUB, DPHI, DPSI, DW,
+     $                   EPS, ERRETM, ETA, MIDPT, PHI, PREW, PSI,
+     $                   RHOINV, TAU, TEMP, TEMP1, W
 *     ..
 *     .. Local Arrays ..
       DOUBLE PRECISION   ZZ( 3 )
@@ -106,7 +183,7 @@
       EXTERNAL           DLAED5, DLAED6
 *     ..
 *     .. Intrinsic Functions ..
-      INTRINSIC          ABS, SQRT
+      INTRINSIC          ABS, MAX, MIN, SQRT
 *     ..
 *     .. Executable Statements ..
 *
@@ -145,13 +222,13 @@
 *
 *        Calculate initial guess
 *
-         TEMP = RHO / TWO
+         MIDPT = RHO / TWO
 *
 *        If ||Z||_2 is not one, then TEMP should be set to
 *        RHO * ||Z||_2^2 / TWO
 *
          DO 10 J = 1, N
-            DELTA( J ) = ( D( J )-D( I ) ) - TEMP
+            DELTA( J ) = ( D( J )-D( I ) ) - MIDPT
    10    CONTINUE
 *
          PSI = ZERO
@@ -182,6 +259,8 @@
 *           It can be proved that
 *               D(N)+RHO/2 <= LAMBDA(N) < D(N)+TAU <= D(N)+RHO
 *
+            DLTLB = MIDPT
+            DLTUB = RHO
          ELSE
             DEL = D( N ) - D( N-1 )
             A = -C*DEL + Z( N-1 )*Z( N-1 ) + Z( N )*Z( N )
@@ -195,6 +274,8 @@
 *           It can be proved that
 *               D(N) < D(N)+TAU < LAMBDA(N) < D(N)+RHO/2
 *
+            DLTLB = ZERO
+            DLTUB = MIDPT
          END IF
 *
          DO 30 J = 1, N
@@ -230,6 +311,12 @@
             DLAM = D( I ) + TAU
             GO TO 250
          END IF
+*
+         IF( W.LE.ZERO ) THEN
+            DLTLB = MAX( DLTLB, TAU )
+         ELSE
+            DLTUB = MIN( DLTUB, TAU )
+         END IF
 *
 *        Calculate the new step
 *
@@ -242,7 +329,8 @@
      $      C = ABS( C )
          IF( C.EQ.ZERO ) THEN
 *          ETA = B/A
-            ETA = RHO - TAU
+*           ETA = RHO - TAU
+            ETA = DLTUB - TAU
          ELSE IF( A.GE.ZERO ) THEN
             ETA = ( A+SQRT( ABS( A*A-FOUR*B*C ) ) ) / ( TWO*C )
          ELSE
@@ -258,8 +346,13 @@
          IF( W*ETA.GT.ZERO )
      $      ETA = -W / ( DPSI+DPHI )
          TEMP = TAU + ETA
-         IF( TEMP.GT.RHO )
-     $      ETA = RHO - TAU
+         IF( TEMP.GT.DLTUB .OR. TEMP.LT.DLTLB ) THEN
+            IF( W.LT.ZERO ) THEN
+               ETA = ( DLTUB-TAU ) / TWO
+            ELSE
+               ETA = ( DLTLB-TAU ) / TWO
+            END IF
+         END IF
          DO 50 J = 1, N
             DELTA( J ) = DELTA( J ) - ETA
    50    CONTINUE
@@ -301,6 +394,12 @@
                DLAM = D( I ) + TAU
                GO TO 250
             END IF
+*
+            IF( W.LE.ZERO ) THEN
+               DLTLB = MAX( DLTLB, TAU )
+            ELSE
+               DLTUB = MIN( DLTUB, TAU )
+            END IF
 *
 *           Calculate the new step
 *
@@ -323,8 +422,13 @@
             IF( W*ETA.GT.ZERO )
      $         ETA = -W / ( DPSI+DPHI )
             TEMP = TAU + ETA
-            IF( TEMP.LE.ZERO )
-     $         ETA = ETA / TWO
+            IF( TEMP.GT.DLTUB .OR. TEMP.LT.DLTLB ) THEN
+               IF( W.LT.ZERO ) THEN
+                  ETA = ( DLTUB-TAU ) / TWO
+               ELSE
+                  ETA = ( DLTLB-TAU ) / TWO
+               END IF
+            END IF
             DO 70 J = 1, N
                DELTA( J ) = DELTA( J ) - ETA
    70       CONTINUE
@@ -372,9 +476,10 @@
 *
 *        Calculate initial guess
 *
-         TEMP = ( D( IP1 )-D( I ) ) / TWO
+         DEL = D( IP1 ) - D( I )
+         MIDPT = DEL / TWO
          DO 100 J = 1, N
-            DELTA( J ) = ( D( J )-D( I ) ) - TEMP
+            DELTA( J ) = ( D( J )-D( I ) ) - MIDPT
   100    CONTINUE
 *
          PSI = ZERO
@@ -397,7 +502,6 @@
 *           We choose d(i) as origin.
 *
             ORGATI = .TRUE.
-            DEL = D( IP1 ) - D( I )
             A = C*DEL + Z( I )*Z( I ) + Z( IP1 )*Z( IP1 )
             B = Z( I )*Z( I )*DEL
             IF( A.GT.ZERO ) THEN
@@ -405,6 +509,8 @@
             ELSE
                TAU = ( A-SQRT( ABS( A*A-FOUR*B*C ) ) ) / ( TWO*C )
             END IF
+            DLTLB = ZERO
+            DLTUB = MIDPT
          ELSE
 *
 *           (d(i)+d(i+1))/2 <= the ith eigenvalue < d(i+1)
@@ -412,7 +518,6 @@
 *           We choose d(i+1) as origin.
 *
             ORGATI = .FALSE.
-            DEL = D( IP1 ) - D( I )
             A = C*DEL - Z( I )*Z( I ) - Z( IP1 )*Z( IP1 )
             B = Z( IP1 )*Z( IP1 )*DEL
             IF( A.LT.ZERO ) THEN
@@ -420,6 +525,8 @@
             ELSE
                TAU = -( A+SQRT( ABS( A*A+FOUR*B*C ) ) ) / ( TWO*C )
             END IF
+            DLTLB = -MIDPT
+            DLTUB = ZERO
          END IF
 *
          IF( ORGATI ) THEN
@@ -496,6 +603,12 @@
             END IF
             GO TO 250
          END IF
+*
+         IF( W.LE.ZERO ) THEN
+            DLTLB = MAX( DLTLB, TAU )
+         ELSE
+            DLTUB = MIN( DLTUB, TAU )
+         END IF
 *
 *        Calculate the new step
 *
@@ -565,22 +678,16 @@
          IF( W*ETA.GE.ZERO )
      $      ETA = -W / DW
          TEMP = TAU + ETA
-         DEL = ( D( IP1 )-D( I ) ) / TWO
-         IF( ORGATI ) THEN
-            IF( TEMP.GE.DEL )
-     $         ETA = DEL - TAU
-            IF( TEMP.LE.ZERO )
-     $         ETA = ETA / TWO
-         ELSE
-            IF( TEMP.LE.-DEL )
-     $         ETA = -DEL - TAU
-            IF( TEMP.GE.ZERO )
-     $         ETA = ETA / TWO
+         IF( TEMP.GT.DLTUB .OR. TEMP.LT.DLTLB ) THEN
+            IF( W.LT.ZERO ) THEN
+               ETA = ( DLTUB-TAU ) / TWO
+            ELSE
+               ETA = ( DLTLB-TAU ) / TWO
+            END IF
          END IF
 *
          PREW = W
 *
-  170    CONTINUE
          DO 180 J = 1, N
             DELTA( J ) = DELTA( J ) - ETA
   180    CONTINUE
@@ -643,6 +750,12 @@
                END IF
                GO TO 250
             END IF
+*
+            IF( W.LE.ZERO ) THEN
+               DLTLB = MAX( DLTLB, TAU )
+            ELSE
+               DLTUB = MIN( DLTUB, TAU )
+            END IF
 *
 *           Calculate the new step
 *
@@ -731,17 +844,12 @@
             IF( W*ETA.GE.ZERO )
      $         ETA = -W / DW
             TEMP = TAU + ETA
-            DEL = ( D( IP1 )-D( I ) ) / TWO
-            IF( ORGATI ) THEN
-               IF( TEMP.GE.DEL )
-     $            ETA = DEL - TAU
-               IF( TEMP.LE.ZERO )
-     $            ETA = ETA / TWO
-            ELSE
-               IF( TEMP.LE.-DEL )
-     $            ETA = -DEL - TAU
-               IF( TEMP.GE.ZERO )
-     $            ETA = ETA / TWO
+            IF( TEMP.GT.DLTUB .OR. TEMP.LT.DLTLB ) THEN
+               IF( W.LT.ZERO ) THEN
+                  ETA = ( DLTUB-TAU ) / TWO
+               ELSE
+                  ETA = ( DLTLB-TAU ) / TWO
+               END IF
             END IF
 *
             DO 210 J = 1, N
@@ -798,6 +906,7 @@
       END IF
 *
   250 CONTINUE
+*
       RETURN
 *
 *     End of DLAED4
