@@ -1,9 +1,96 @@
+*> \brief \b CGET37
+*
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at
+*            http://www.netlib.org/lapack/explore-html/
+*
+*  Definition:
+*  ===========
+*
+*       SUBROUTINE CGET37( RMAX, LMAX, NINFO, KNT, NIN )
+*
+*       .. Scalar Arguments ..
+*       INTEGER            KNT, NIN
+*       ..
+*       .. Array Arguments ..
+*       INTEGER            LMAX( 3 ), NINFO( 3 )
+*       REAL               RMAX( 3 )
+*       ..
+*
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*> CGET37 tests CTRSNA, a routine for estimating condition numbers of
+*> eigenvalues and/or right eigenvectors of a matrix.
+*>
+*> The test matrices are read from a file with logical unit number NIN.
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[out] RMAX
+*> \verbatim
+*>          RMAX is REAL array, dimension (3)
+*>          Value of the largest test ratio.
+*>          RMAX(1) = largest ratio comparing different calls to CTRSNA
+*>          RMAX(2) = largest error in reciprocal condition
+*>                    numbers taking their conditioning into account
+*>          RMAX(3) = largest error in reciprocal condition
+*>                    numbers not taking their conditioning into
+*>                    account (may be larger than RMAX(2))
+*> \endverbatim
+*>
+*> \param[out] LMAX
+*> \verbatim
+*>          LMAX is INTEGER array, dimension (3)
+*>          LMAX(i) is example number where largest test ratio
+*>          RMAX(i) is achieved. Also:
+*>          If CGEHRD returns INFO nonzero on example i, LMAX(1)=i
+*>          If CHSEQR returns INFO nonzero on example i, LMAX(2)=i
+*>          If CTRSNA returns INFO nonzero on example i, LMAX(3)=i
+*> \endverbatim
+*>
+*> \param[out] NINFO
+*> \verbatim
+*>          NINFO is INTEGER array, dimension (3)
+*>          NINFO(1) = No. of times CGEHRD returned INFO nonzero
+*>          NINFO(2) = No. of times CHSEQR returned INFO nonzero
+*>          NINFO(3) = No. of times CTRSNA returned INFO nonzero
+*> \endverbatim
+*>
+*> \param[out] KNT
+*> \verbatim
+*>          KNT is INTEGER
+*>          Total number of examples tested.
+*> \endverbatim
+*>
+*> \param[in] NIN
+*> \verbatim
+*>          NIN is INTEGER
+*>          Input logical unit number
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee
+*> \author Univ. of California Berkeley
+*> \author Univ. of Colorado Denver
+*> \author NAG Ltd.
+*
+*> \ingroup complex_eig
+*
+*  =====================================================================
       SUBROUTINE CGET37( RMAX, LMAX, NINFO, KNT, NIN )
 *
-*  -- LAPACK test routine (version 2.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     February 29, 1992
+*  -- LAPACK test routine --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
 *
 *     .. Scalar Arguments ..
       INTEGER            KNT, NIN
@@ -13,44 +100,6 @@
       REAL               RMAX( 3 )
 *     ..
 *
-*  Purpose
-*  =======
-*
-*  CGET37 tests CTRSNA, a routine for estimating condition numbers of
-*  eigenvalues and/or right eigenvectors of a matrix.
-*
-*  The test matrices are read from a file with logical unit number NIN.
-*
-*  Arguments
-*  ==========
-*
-*  RMAX    (output) REAL array, dimension (3)
-*          Value of the largest test ratio.
-*          RMAX(1) = largest ratio comparing different calls to CTRSNA
-*          RMAX(2) = largest error in reciprocal condition
-*                    numbers taking their conditioning into account
-*          RMAX(3) = largest error in reciprocal condition
-*                    numbers not taking their conditioning into
-*                    account (may be larger than RMAX(2))
-*
-*  LMAX    (output) INTEGER array, dimension (3)
-*          LMAX(i) is example number where largest test ratio
-*          RMAX(i) is achieved. Also:
-*          If CGEHRD returns INFO nonzero on example i, LMAX(1)=i
-*          If CHSEQR returns INFO nonzero on example i, LMAX(2)=i
-*          If CTRSNA returns INFO nonzero on example i, LMAX(3)=i
-*
-*  NINFO   (output) INTEGER array, dimension (3)
-*          NINFO(1) = 1 if CGEHRD returned INFO nonzero
-*          NINFO(2) = 1 if CHSEQR returned INFO nonzero
-*          NINFO(3) = 1 if CTRSNA returned INFO nonzero
-*
-*  KNT     (output) INTEGER
-*          Total number of examples tested.
-*
-*  NIN     (input) INTEGER
-*          Input logical unit number
-*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -83,7 +132,7 @@
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           CCOPY, CGEHRD, CHSEQR, CLACPY, CSSCAL, CTREVC,
-     $                   CTRSNA, SCOPY, SSCAL
+     $                   CTRSNA, SCOPY, SLABAD, SSCAL
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          AIMAG, MAX, REAL, SQRT
@@ -147,7 +196,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 1 ) = KNT
             NINFO( 1 ) = NINFO( 1 ) + 1
-            RETURN
+            GO TO 260
          END IF
          DO 60 J = 1, N - 2
             DO 50 I = J + 2, N
@@ -162,7 +211,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 2 ) = KNT
             NINFO( 2 ) = NINFO( 2 ) + 1
-            RETURN
+            GO TO 260
          END IF
 *
 *        Compute eigenvectors
@@ -180,7 +229,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 3 ) = KNT
             NINFO( 3 ) = NINFO( 3 ) + 1
-            RETURN
+            GO TO 260
          END IF
 *
 *        Sort eigenvalues and condition numbers lexicographically
@@ -259,7 +308,8 @@
             END IF
             IF( VMAX.GT.RMAX( 2 ) ) THEN
                RMAX( 2 ) = VMAX
-               LMAX( 2 ) = KNT
+               IF( NINFO( 2 ).EQ.0 )
+     $            LMAX( 2 ) = KNT
             END IF
   120    CONTINUE
 *
@@ -292,7 +342,8 @@
             END IF
             IF( VMAX.GT.RMAX( 2 ) ) THEN
                RMAX( 2 ) = VMAX
-               LMAX( 2 ) = KNT
+               IF( NINFO( 2 ).EQ.0 )
+     $            LMAX( 2 ) = KNT
             END IF
   130    CONTINUE
 *
@@ -316,7 +367,8 @@
             END IF
             IF( VMAX.GT.RMAX( 3 ) ) THEN
                RMAX( 3 ) = VMAX
-               LMAX( 3 ) = KNT
+               IF( NINFO( 3 ).EQ.0 )
+     $            LMAX( 3 ) = KNT
             END IF
   140    CONTINUE
 *
@@ -339,7 +391,8 @@
             END IF
             IF( VMAX.GT.RMAX( 3 ) ) THEN
                RMAX( 3 ) = VMAX
-               LMAX( 3 ) = KNT
+               IF( NINFO( 3 ).EQ.0 )
+     $            LMAX( 3 ) = KNT
             END IF
   150    CONTINUE
 *
@@ -354,7 +407,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 3 ) = KNT
             NINFO( 3 ) = NINFO( 3 ) + 1
-            RETURN
+            GO TO 260
          END IF
          DO 160 I = 1, N
             IF( STMP( I ).NE.S( I ) )
@@ -372,7 +425,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 3 ) = KNT
             NINFO( 3 ) = NINFO( 3 ) + 1
-            RETURN
+            GO TO 260
          END IF
          DO 170 I = 1, N
             IF( STMP( I ).NE.DUM( 1 ) )
@@ -393,7 +446,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 3 ) = KNT
             NINFO( 3 ) = NINFO( 3 ) + 1
-            RETURN
+            GO TO 260
          END IF
          DO 190 I = 1, N
             IF( SEPTMP( I ).NE.SEP( I ) )
@@ -411,7 +464,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 3 ) = KNT
             NINFO( 3 ) = NINFO( 3 ) + 1
-            RETURN
+            GO TO 260
          END IF
          DO 200 I = 1, N
             IF( STMP( I ).NE.S( I ) )
@@ -429,7 +482,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 3 ) = KNT
             NINFO( 3 ) = NINFO( 3 ) + 1
-            RETURN
+            GO TO 260
          END IF
          DO 210 I = 1, N
             IF( STMP( I ).NE.DUM( 1 ) )
@@ -439,7 +492,8 @@
   210    CONTINUE
          IF( VMAX.GT.RMAX( 1 ) ) THEN
             RMAX( 1 ) = VMAX
-            LMAX( 1 ) = KNT
+            IF( NINFO( 1 ).EQ.0 )
+     $         LMAX( 1 ) = KNT
          END IF
 *
 *        Select second and next to last eigenvalues
@@ -472,7 +526,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 3 ) = KNT
             NINFO( 3 ) = NINFO( 3 ) + 1
-            RETURN
+            GO TO 260
          END IF
          DO 230 I = 1, ICMP
             J = LCMP( I )
@@ -491,7 +545,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 3 ) = KNT
             NINFO( 3 ) = NINFO( 3 ) + 1
-            RETURN
+            GO TO 260
          END IF
          DO 240 I = 1, ICMP
             J = LCMP( I )
@@ -510,7 +564,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 3 ) = KNT
             NINFO( 3 ) = NINFO( 3 ) + 1
-            RETURN
+            GO TO 260
          END IF
          DO 250 I = 1, ICMP
             J = LCMP( I )
@@ -521,7 +575,8 @@
   250    CONTINUE
          IF( VMAX.GT.RMAX( 1 ) ) THEN
             RMAX( 1 ) = VMAX
-            LMAX( 1 ) = KNT
+            IF( NINFO( 1 ).EQ.0 )
+     $         LMAX( 1 ) = KNT
          END IF
   260 CONTINUE
       GO TO 10
