@@ -1,30 +1,67 @@
+*> \brief \b DERRQR
+*
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at
+*            http://www.netlib.org/lapack/explore-html/
+*
+*  Definition:
+*  ===========
+*
+*       SUBROUTINE DERRQR( PATH, NUNIT )
+*
+*       .. Scalar Arguments ..
+*       CHARACTER*3        PATH
+*       INTEGER            NUNIT
+*       ..
+*
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*> DERRQR tests the error exits for the DOUBLE PRECISION routines
+*> that use the QR decomposition of a general matrix.
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[in] PATH
+*> \verbatim
+*>          PATH is CHARACTER*3
+*>          The LAPACK path name for the routines to be tested.
+*> \endverbatim
+*>
+*> \param[in] NUNIT
+*> \verbatim
+*>          NUNIT is INTEGER
+*>          The unit number for output.
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee
+*> \author Univ. of California Berkeley
+*> \author Univ. of Colorado Denver
+*> \author NAG Ltd.
+*
+*> \ingroup double_lin
+*
+*  =====================================================================
       SUBROUTINE DERRQR( PATH, NUNIT )
 *
-*  -- LAPACK test routine (version 3.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     February 29, 1992
+*  -- LAPACK test routine --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
 *
 *     .. Scalar Arguments ..
       CHARACTER*3        PATH
       INTEGER            NUNIT
 *     ..
 *
-*  Purpose
-*  =======
-*
-*  DERRQR tests the error exits for the DOUBLE PRECISION routines
-*  that use the QR decomposition of a general matrix.
-*
-*  Arguments
-*  =========
-*
-*  PATH    (input) CHARACTER*3
-*          The LAPACK path name for the routines to be tested.
-*
-*  NUNIT   (input) INTEGER
-*          The unit number for output.
-*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -39,12 +76,13 @@
      $                   W( NMAX ), X( NMAX )
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           ALAESM, CHKXER, DGEQR2, DGEQRF, DGEQRS, DORG2R,
-     $                   DORGQR, DORM2R, DORMQR
+      EXTERNAL           ALAESM, CHKXER, DGEQR2, DGEQR2P, DGEQRF,
+     $                   DGEQRFP, DGEQRS, DORG2R, DORGQR, DORM2R,
+     $                   DORMQR
 *     ..
 *     .. Scalars in Common ..
       LOGICAL            LERR, OK
-      CHARACTER*6        SRNAMT
+      CHARACTER*32       SRNAMT
       INTEGER            INFOT, NOUT
 *     ..
 *     .. Common blocks ..
@@ -90,6 +128,22 @@
       CALL DGEQRF( 1, 2, A, 1, B, W, 1, INFO )
       CALL CHKXER( 'DGEQRF', INFOT, NOUT, LERR, OK )
 *
+*     DGEQRFP
+*
+      SRNAMT = 'DGEQRFP'
+      INFOT = 1
+      CALL DGEQRFP( -1, 0, A, 1, B, W, 1, INFO )
+      CALL CHKXER( 'DGEQRFP', INFOT, NOUT, LERR, OK )
+      INFOT = 2
+      CALL DGEQRFP( 0, -1, A, 1, B, W, 1, INFO )
+      CALL CHKXER( 'DGEQRFP', INFOT, NOUT, LERR, OK )
+      INFOT = 4
+      CALL DGEQRFP( 2, 1, A, 1, B, W, 1, INFO )
+      CALL CHKXER( 'DGEQRFP', INFOT, NOUT, LERR, OK )
+      INFOT = 7
+      CALL DGEQRFP( 1, 2, A, 1, B, W, 1, INFO )
+      CALL CHKXER( 'DGEQRFP', INFOT, NOUT, LERR, OK )
+*
 *     DGEQR2
 *
       SRNAMT = 'DGEQR2'
@@ -103,6 +157,19 @@
       CALL DGEQR2( 2, 1, A, 1, B, W, INFO )
       CALL CHKXER( 'DGEQR2', INFOT, NOUT, LERR, OK )
 *
+*     DGEQR2P
+*
+      SRNAMT = 'DGEQR2P'
+      INFOT = 1
+      CALL DGEQR2P( -1, 0, A, 1, B, W, INFO )
+      CALL CHKXER( 'DGEQR2P', INFOT, NOUT, LERR, OK )
+      INFOT = 2
+      CALL DGEQR2P( 0, -1, A, 1, B, W, INFO )
+      CALL CHKXER( 'DGEQR2P', INFOT, NOUT, LERR, OK )
+      INFOT = 4
+      CALL DGEQR2P( 2, 1, A, 1, B, W, INFO )
+      CALL CHKXER( 'DGEQR2P', INFOT, NOUT, LERR, OK )
+*
 *     DGEQRS
 *
       SRNAMT = 'DGEQRS'
