@@ -1,95 +1,207 @@
-      SUBROUTINE ZCHKGE( DOTYPE, NM, MVAL, NN, NVAL, NNB, NBVAL, NRHS,
-     $                   THRESH, TSTERR, NMAX, A, AFAC, AINV, B, X,
-     $                   XACT, WORK, RWORK, IWORK, NOUT )
+*> \brief \b ZCHKGE
 *
-*  -- LAPACK test routine (version 2.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at
+*            http://www.netlib.org/lapack/explore-html/
+*
+*  Definition:
+*  ===========
+*
+*       SUBROUTINE ZCHKGE( DOTYPE, NM, MVAL, NN, NVAL, NNB, NBVAL, NNS,
+*                          NSVAL, THRESH, TSTERR, NMAX, A, AFAC, AINV, B,
+*                          X, XACT, WORK, RWORK, IWORK, NOUT )
+*
+*       .. Scalar Arguments ..
+*       LOGICAL            TSTERR
+*       INTEGER            NM, NMAX, NN, NNB, NNS, NOUT
+*       DOUBLE PRECISION   THRESH
+*       ..
+*       .. Array Arguments ..
+*       LOGICAL            DOTYPE( * )
+*       INTEGER            IWORK( * ), MVAL( * ), NBVAL( * ), NSVAL( * ),
+*      $                   NVAL( * )
+*       DOUBLE PRECISION   RWORK( * )
+*       COMPLEX*16         A( * ), AFAC( * ), AINV( * ), B( * ),
+*      $                   WORK( * ), X( * ), XACT( * )
+*       ..
+*
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*> ZCHKGE tests ZGETRF, -TRI, -TRS, -RFS, and -CON.
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[in] DOTYPE
+*> \verbatim
+*>          DOTYPE is LOGICAL array, dimension (NTYPES)
+*>          The matrix types to be used for testing.  Matrices of type j
+*>          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
+*>          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
+*> \endverbatim
+*>
+*> \param[in] NM
+*> \verbatim
+*>          NM is INTEGER
+*>          The number of values of M contained in the vector MVAL.
+*> \endverbatim
+*>
+*> \param[in] MVAL
+*> \verbatim
+*>          MVAL is INTEGER array, dimension (NM)
+*>          The values of the matrix row dimension M.
+*> \endverbatim
+*>
+*> \param[in] NN
+*> \verbatim
+*>          NN is INTEGER
+*>          The number of values of N contained in the vector NVAL.
+*> \endverbatim
+*>
+*> \param[in] NVAL
+*> \verbatim
+*>          NVAL is INTEGER array, dimension (NN)
+*>          The values of the matrix column dimension N.
+*> \endverbatim
+*>
+*> \param[in] NNB
+*> \verbatim
+*>          NNB is INTEGER
+*>          The number of values of NB contained in the vector NBVAL.
+*> \endverbatim
+*>
+*> \param[in] NBVAL
+*> \verbatim
+*>          NBVAL is INTEGER array, dimension (NNB)
+*>          The values of the blocksize NB.
+*> \endverbatim
+*>
+*> \param[in] NNS
+*> \verbatim
+*>          NNS is INTEGER
+*>          The number of values of NRHS contained in the vector NSVAL.
+*> \endverbatim
+*>
+*> \param[in] NSVAL
+*> \verbatim
+*>          NSVAL is INTEGER array, dimension (NNS)
+*>          The values of the number of right hand sides NRHS.
+*> \endverbatim
+*>
+*> \param[in] THRESH
+*> \verbatim
+*>          THRESH is DOUBLE PRECISION
+*>          The threshold value for the test ratios.  A result is
+*>          included in the output file if RESULT >= THRESH.  To have
+*>          every test ratio printed, use THRESH = 0.
+*> \endverbatim
+*>
+*> \param[in] TSTERR
+*> \verbatim
+*>          TSTERR is LOGICAL
+*>          Flag that indicates whether error exits are to be tested.
+*> \endverbatim
+*>
+*> \param[in] NMAX
+*> \verbatim
+*>          NMAX is INTEGER
+*>          The maximum value permitted for M or N, used in dimensioning
+*>          the work arrays.
+*> \endverbatim
+*>
+*> \param[out] A
+*> \verbatim
+*>          A is COMPLEX*16 array, dimension (NMAX*NMAX)
+*> \endverbatim
+*>
+*> \param[out] AFAC
+*> \verbatim
+*>          AFAC is COMPLEX*16 array, dimension (NMAX*NMAX)
+*> \endverbatim
+*>
+*> \param[out] AINV
+*> \verbatim
+*>          AINV is COMPLEX*16 array, dimension (NMAX*NMAX)
+*> \endverbatim
+*>
+*> \param[out] B
+*> \verbatim
+*>          B is COMPLEX*16 array, dimension (NMAX*NSMAX)
+*>          where NSMAX is the largest entry in NSVAL.
+*> \endverbatim
+*>
+*> \param[out] X
+*> \verbatim
+*>          X is COMPLEX*16 array, dimension (NMAX*NSMAX)
+*> \endverbatim
+*>
+*> \param[out] XACT
+*> \verbatim
+*>          XACT is COMPLEX*16 array, dimension (NMAX*NSMAX)
+*> \endverbatim
+*>
+*> \param[out] WORK
+*> \verbatim
+*>          WORK is COMPLEX*16 array, dimension
+*>                      (NMAX*max(3,NSMAX))
+*> \endverbatim
+*>
+*> \param[out] RWORK
+*> \verbatim
+*>          RWORK is DOUBLE PRECISION array, dimension
+*>                      (max(2*NMAX,2*NSMAX+NWORK))
+*> \endverbatim
+*>
+*> \param[out] IWORK
+*> \verbatim
+*>          IWORK is INTEGER array, dimension (NMAX)
+*> \endverbatim
+*>
+*> \param[in] NOUT
+*> \verbatim
+*>          NOUT is INTEGER
+*>          The unit number for output.
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee
+*> \author Univ. of California Berkeley
+*> \author Univ. of Colorado Denver
+*> \author NAG Ltd.
+*
+*> \ingroup complex16_lin
+*
+*  =====================================================================
+      SUBROUTINE ZCHKGE( DOTYPE, NM, MVAL, NN, NVAL, NNB, NBVAL, NNS,
+     $                   NSVAL, THRESH, TSTERR, NMAX, A, AFAC, AINV, B,
+     $                   X, XACT, WORK, RWORK, IWORK, NOUT )
+*
+*  -- LAPACK test routine --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
 *
 *     .. Scalar Arguments ..
       LOGICAL            TSTERR
-      INTEGER            NM, NMAX, NN, NNB, NOUT, NRHS
+      INTEGER            NM, NMAX, NN, NNB, NNS, NOUT
       DOUBLE PRECISION   THRESH
 *     ..
 *     .. Array Arguments ..
       LOGICAL            DOTYPE( * )
-      INTEGER            IWORK( * ), MVAL( * ), NBVAL( * ), NVAL( * )
+      INTEGER            IWORK( * ), MVAL( * ), NBVAL( * ), NSVAL( * ),
+     $                   NVAL( * )
       DOUBLE PRECISION   RWORK( * )
       COMPLEX*16         A( * ), AFAC( * ), AINV( * ), B( * ),
      $                   WORK( * ), X( * ), XACT( * )
 *     ..
 *
-*  Purpose
-*  =======
-*
-*  ZCHKGE tests ZGETRF, -TRI, -TRS, -RFS, and -CON.
-*
-*  Arguments
-*  =========
-*
-*  DOTYPE  (input) LOGICAL array, dimension (NTYPES)
-*          The matrix types to be used for testing.  Matrices of type j
-*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
-*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
-*
-*  NM      (input) INTEGER
-*          The number of values of M contained in the vector MVAL.
-*
-*  MVAL    (input) INTEGER array, dimension (NM)
-*          The values of the matrix row dimension M.
-*
-*  NN      (input) INTEGER
-*          The number of values of N contained in the vector NVAL.
-*
-*  NVAL    (input) INTEGER array, dimension (NN)
-*          The values of the matrix column dimension N.
-*
-*  NNB     (input) INTEGER
-*          The number of values of NB contained in the vector NBVAL.
-*
-*  NBVAL   (input) INTEGER array, dimension (NBVAL)
-*          The values of the blocksize NB.
-*
-*  NRHS    (input) INTEGER
-*          The number of right hand side vectors to be generated for
-*          each linear system.
-*
-*  THRESH  (input) DOUBLE PRECISION
-*          The threshold value for the test ratios.  A result is
-*          included in the output file if RESULT >= THRESH.  To have
-*          every test ratio printed, use THRESH = 0.
-*
-*  TSTERR  (input) LOGICAL
-*          Flag that indicates whether error exits are to be tested.
-*
-*  NMAX    (input) INTEGER
-*          The maximum value permitted for M or N, used in dimensioning
-*          the work arrays.
-*
-*  A       (workspace) COMPLEX*16 array, dimension (NMAX*NMAX)
-*
-*  AFAC    (workspace) COMPLEX*16 array, dimension (NMAX*NMAX)
-*
-*  AINV    (workspace) COMPLEX*16 array, dimension (NMAX*NMAX)
-*
-*  B       (workspace) COMPLEX*16 array, dimension (NMAX*NRHS)
-*
-*  X       (workspace) COMPLEX*16 array, dimension (NMAX*NRHS)
-*
-*  XACT    (workspace) COMPLEX*16 array, dimension (NMAX*NRHS)
-*
-*  WORK    (workspace) COMPLEX*16 array, dimension
-*                      (NMAX*max(3,NRHS))
-*
-*  RWORK   (workspace) DOUBLE PRECISION array, dimension
-*                      (max(2*NMAX,2*NRHS+NWORK))
-*
-*  IWORK   (workspace) INTEGER array, dimension (NMAX)
-*
-*  NOUT    (input) INTEGER
-*          The unit number for output.
-*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -106,9 +218,9 @@
       LOGICAL            TRFCON, ZEROT
       CHARACTER          DIST, NORM, TRANS, TYPE, XTYPE
       CHARACTER*3        PATH
-      INTEGER            I, IM, IMAT, IN, INB, INFO, IOFF, ITRAN, IZERO,
-     $                   K, K1, KL, KU, LDA, LWORK, M, MODE, N, NB,
-     $                   NERRS, NFAIL, NIMAT, NRUN, NT
+      INTEGER            I, IM, IMAT, IN, INB, INFO, IOFF, IRHS, ITRAN,
+     $                   IZERO, K, KL, KU, LDA, LWORK, M, MODE, N, NB,
+     $                   NERRS, NFAIL, NIMAT, NRHS, NRUN, NT
       DOUBLE PRECISION   AINVNM, ANORM, ANORMI, ANORMO, CNDNUM, DUMMY,
      $                   RCOND, RCONDC, RCONDI, RCONDO
 *     ..
@@ -132,7 +244,7 @@
 *     ..
 *     .. Scalars in Common ..
       LOGICAL            LERR, OK
-      CHARACTER*6        SRNAMT
+      CHARACTER*32       SRNAMT
       INTEGER            INFOT, NUNIT
 *     ..
 *     .. Common blocks ..
@@ -147,7 +259,7 @@
 *
 *     Initialize constants and the random number seed.
 *
-      PATH( 1: 1 ) = 'Z'
+      PATH( 1: 1 ) = 'Zomplex precision'
       PATH( 2: 3 ) = 'GE'
       NRUN = 0
       NFAIL = 0
@@ -158,6 +270,7 @@
 *
 *     Test the error exits
 *
+      CALL XLAENV( 1, 1 )
       IF( TSTERR )
      $   CALL ZERRGE( PATH, NOUT )
       INFOT = 0
@@ -165,31 +278,31 @@
 *
 *     Do for each value of M in MVAL
 *
-      DO 90 IM = 1, NM
+      DO 120 IM = 1, NM
          M = MVAL( IM )
          LDA = MAX( 1, M )
 *
 *        Do for each value of N in NVAL
 *
-         DO 80 IN = 1, NN
+         DO 110 IN = 1, NN
             N = NVAL( IN )
             XTYPE = 'N'
             NIMAT = NTYPES
             IF( M.LE.0 .OR. N.LE.0 )
      $         NIMAT = 1
 *
-            DO 70 IMAT = 1, NIMAT
+            DO 100 IMAT = 1, NIMAT
 *
 *              Do the tests only if DOTYPE( IMAT ) is true.
 *
                IF( .NOT.DOTYPE( IMAT ) )
-     $            GO TO 70
+     $            GO TO 100
 *
 *              Skip types 5, 6, or 7 if the matrix size is too small.
 *
                ZEROT = IMAT.GE.5 .AND. IMAT.LE.7
                IF( ZEROT .AND. N.LT.IMAT-4 )
-     $            GO TO 70
+     $            GO TO 100
 *
 *              Set up parameters with ZLATB4 and generate a test matrix
 *              with ZLATMS.
@@ -207,7 +320,7 @@
                IF( INFO.NE.0 ) THEN
                   CALL ALAERH( PATH, 'ZLATMS', INFO, 0, ' ', M, N, -1,
      $                         -1, -1, IMAT, NFAIL, NERRS, NOUT )
-                  GO TO 70
+                  GO TO 100
                END IF
 *
 *              For types 5-7, zero one or more columns of the matrix to
@@ -242,7 +355,7 @@
 *
 *              Do for each blocksize in NBVAL
 *
-               DO 60 INB = 1, NNB
+               DO 90 INB = 1, NNB
                   NB = NBVAL( INB )
                   CALL XLAENV( 1, NB )
 *
@@ -275,6 +388,7 @@
                   IF( M.EQ.N .AND. INFO.EQ.0 ) THEN
                      CALL ZLACPY( 'Full', N, N, AFAC, LDA, AINV, LDA )
                      SRNAMT = 'ZGETRI'
+                     NRHS = NSVAL( 1 )
                      LWORK = NMAX*MAX( 3, NRHS )
                      CALL ZGETRI( N, AINV, LDA, IWORK, WORK, LWORK,
      $                            INFO )
@@ -330,26 +444,25 @@
                   NRUN = NRUN + NT
 *
 *                 Skip the remaining tests if this is not the first
-*                 block size or if M .ne. N.
+*                 block size or if M .ne. N.  Skip the solve tests if
+*                 the matrix is singular.
 *
                   IF( INB.GT.1 .OR. M.NE.N )
-     $               GO TO 60
+     $               GO TO 90
+                  IF( TRFCON )
+     $               GO TO 70
 *
-                  DO 50 ITRAN = 1, NTRAN
-                     TRANS = TRANSS( ITRAN )
-                     IF( ITRAN.EQ.1 ) THEN
-                        ANORM = ANORMO
-                        RCONDC = RCONDO
-                        NORM = 'O'
-                     ELSE
-                        ANORM = ANORMI
-                        RCONDC = RCONDI
-                        NORM = 'I'
-                     END IF
-                     IF( TRFCON ) THEN
-                        K1 = 8
-                     ELSE
-                        K1 = 3
+                  DO 60 IRHS = 1, NNS
+                     NRHS = NSVAL( IRHS )
+                     XTYPE = 'N'
+*
+                     DO 50 ITRAN = 1, NTRAN
+                        TRANS = TRANSS( ITRAN )
+                        IF( ITRAN.EQ.1 ) THEN
+                           RCONDC = RCONDO
+                        ELSE
+                           RCONDC = RCONDI
+                        END IF
 *
 *+    TEST 3
 *                       Solve and compute residual for A * X = B.
@@ -403,69 +516,84 @@
                         CALL ZGET04( N, NRHS, X, LDA, XACT, LDA, RCONDC,
      $                               RESULT( 5 ) )
                         CALL ZGET07( TRANS, N, NRHS, A, LDA, B, LDA, X,
-     $                               LDA, XACT, LDA, RWORK,
+     $                               LDA, XACT, LDA, RWORK, .TRUE.,
      $                               RWORK( NRHS+1 ), RESULT( 6 ) )
-                        NT = 7
-                     END IF
+*
+*                       Print information about the tests that did not
+*                       pass the threshold.
+*
+                        DO 40 K = 3, 7
+                           IF( RESULT( K ).GE.THRESH ) THEN
+                              IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
+     $                           CALL ALAHD( NOUT, PATH )
+                              WRITE( NOUT, FMT = 9998 )TRANS, N, NRHS,
+     $                           IMAT, K, RESULT( K )
+                              NFAIL = NFAIL + 1
+                           END IF
+   40                   CONTINUE
+                        NRUN = NRUN + 5
+   50                CONTINUE
+   60             CONTINUE
 *
 *+    TEST 8
 *                    Get an estimate of RCOND = 1/CNDNUM.
 *
-                     IF( ITRAN.LE.2 ) THEN
-                        SRNAMT = 'ZGECON'
-                        CALL ZGECON( NORM, N, AFAC, LDA, ANORM, RCOND,
-     $                               WORK, RWORK, INFO )
+   70             CONTINUE
+                  DO 80 ITRAN = 1, 2
+                     IF( ITRAN.EQ.1 ) THEN
+                        ANORM = ANORMO
+                        RCONDC = RCONDO
+                        NORM = 'O'
+                     ELSE
+                        ANORM = ANORMI
+                        RCONDC = RCONDI
+                        NORM = 'I'
+                     END IF
+                     SRNAMT = 'ZGECON'
+                     CALL ZGECON( NORM, N, AFAC, LDA, ANORM, RCOND,
+     $                            WORK, RWORK, INFO )
 *
 *                       Check error code from ZGECON.
 *
-                        IF( INFO.NE.0 )
-     $                     CALL ALAERH( PATH, 'ZGECON', INFO, 0, NORM,
-     $                                  N, N, -1, -1, -1, IMAT, NFAIL,
-     $                                  NERRS, NOUT )
+                     IF( INFO.NE.0 )
+     $                  CALL ALAERH( PATH, 'ZGECON', INFO, 0, NORM, N,
+     $                               N, -1, -1, -1, IMAT, NFAIL, NERRS,
+     $                               NOUT )
 *
 *                       This line is needed on a Sun SPARCstation.
 *
-                        DUMMY = RCOND
+                     DUMMY = RCOND
 *
-                        RESULT( 8 ) = DGET06( RCOND, RCONDC )
-                        NT = 8
-                     END IF
+                     RESULT( 8 ) = DGET06( RCOND, RCONDC )
 *
 *                    Print information about the tests that did not pass
 *                    the threshold.
 *
-                     DO 40 K = K1, NT
-                        IF( RESULT( K ).GE.THRESH ) THEN
-                           IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
-     $                        CALL ALAHD( NOUT, PATH )
-                           IF( K.LT.8 ) THEN
-                              WRITE( NOUT, FMT = 9998 )TRANS, N, NB,
-     $                           IMAT, K, RESULT( K )
-                           ELSE
-                              WRITE( NOUT, FMT = 9997 )NORM, N, NB,
-     $                           IMAT, K, RESULT( K )
-                           END IF
-                           NFAIL = NFAIL + 1
-                        END IF
-   40                CONTINUE
-                     NRUN = NRUN + NT - K1 + 1
-   50             CONTINUE
-   60          CONTINUE
-   70       CONTINUE
+                     IF( RESULT( 8 ).GE.THRESH ) THEN
+                        IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
+     $                     CALL ALAHD( NOUT, PATH )
+                        WRITE( NOUT, FMT = 9997 )NORM, N, IMAT, 8,
+     $                     RESULT( 8 )
+                        NFAIL = NFAIL + 1
+                     END IF
+                     NRUN = NRUN + 1
+   80             CONTINUE
+   90          CONTINUE
+  100       CONTINUE
 *
-   80    CONTINUE
-   90 CONTINUE
+  110    CONTINUE
+  120 CONTINUE
 *
 *     Print a summary of the results.
 *
       CALL ALASUM( PATH, NOUT, NFAIL, NRUN, NERRS )
 *
  9999 FORMAT( ' M = ', I5, ', N =', I5, ', NB =', I4, ', type ', I2,
-     $      ', test ', I2, ', ratio =', G12.5 )
- 9998 FORMAT( ' TRANS=''', A1, ''', N =', I5, ', NB =', I4, ', type ',
-     $      I2, ', test ', I2, ', ratio =', G12.5 )
- 9997 FORMAT( ' NORM =''', A1, ''', N =', I5, ', NB =', I4, ', type ',
-     $      I2, ', test ', I2, ', ratio =', G12.5 )
+     $      ', test(', I2, ') =', G12.5 )
+ 9998 FORMAT( ' TRANS=''', A1, ''', N =', I5, ', NRHS=', I3, ', type ',
+     $      I2, ', test(', I2, ') =', G12.5 )
+ 9997 FORMAT( ' NORM =''', A1, ''', N =', I5, ',', 10X, ' type ', I2,
+     $      ', test(', I2, ') =', G12.5 )
       RETURN
 *
 *     End of ZCHKGE
